==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation.md <==
# AwsCloudFormation


```text
aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation
```

```text
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')
```



| Illustration | AwsCloudFormation | AwsCloudFormationCard | AwsCloudFormationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation.png) | ![illustration for AwsCloudFormation](../../../aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation.Local.png) | ![illustration for AwsCloudFormationCard](../../../aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormationCard.Local.png) | ![illustration for AwsCloudFormationGroup](../../../aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormationGroup.Local.png) |




## AwsCloudFormation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormation
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormation('AwsCloudFormation', 'Aws Cloud Formation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormation
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormation('AwsCloudFormation', 'Aws Cloud Formation', 'an optional tech label')
@enduml
```

## AwsCloudFormationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormationCard
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationCard('AwsCloudFormationCard', 'Aws Cloud Formation Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormationCard
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationCard('AwsCloudFormationCard', 'Aws Cloud Formation Card', 'an optional description')
@enduml
```

## AwsCloudFormationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormationGroup
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationGroup('AwsCloudFormationGroup', 'Aws Cloud Formation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsCloudFormationGroup
include('aws-q3-2021/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationGroup('AwsCloudFormationGroup', 'Aws Cloud Formation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation.md <==
# AwsCloudFormation


```text
aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation
```

```text
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')
```



| Illustration | AwsCloudFormation | AwsCloudFormationCard | AwsCloudFormationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation.png) | ![illustration for AwsCloudFormation](../../../aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation.Local.png) | ![illustration for AwsCloudFormationCard](../../../aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormationCard.Local.png) | ![illustration for AwsCloudFormationGroup](../../../aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormationGroup.Local.png) |




## AwsCloudFormation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormation
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormation('AwsCloudFormation', 'Aws Cloud Formation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormation
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormation('AwsCloudFormation', 'Aws Cloud Formation', 'an optional tech label')
@enduml
```

## AwsCloudFormationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormationCard
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationCard('AwsCloudFormationCard', 'Aws Cloud Formation Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormationCard
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationCard('AwsCloudFormationCard', 'Aws Cloud Formation Card', 'an optional description')
@enduml
```

## AwsCloudFormationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormationGroup
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationGroup('AwsCloudFormationGroup', 'Aws Cloud Formation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsCloudFormationGroup
include('aws-q1-2022/Architecture/ManagementGovernance/AwsCloudFormation')

' renders the element
AwsCloudFormationGroup('AwsCloudFormationGroup', 'Aws Cloud Formation Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
